@@ -52,7 +52,6 @@ struct _PersonalIpAddressPrivate
     GtkWidget *homeWidget;
     GtkWidget *contents;
 	
-	GtkWidget *titleLabel;
 	GtkWidget *ipLabel;
 	GtkWidget *ipContent;
 	
@@ -144,7 +143,7 @@ void personal_ip_address_content_create (PersonalIpAddress *self)
 	gtk_container_set_border_width (GTK_CONTAINER (self->priv->contents), 0);
 	GtkSizeGroup *group = GTK_SIZE_GROUP (gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL));
 
-	GtkWidget *image = gtk_image_new_from_icon_name ("personal-ip-address", GTK_ICON_SIZE_BUTTON);
+	/*GtkWidget *image = gtk_image_new_from_icon_name ("personal-ip-address", GTK_ICON_SIZE_BUTTON);
     self->priv->titleLabel = gtk_label_new ("IP Address");
 	hildon_helper_set_logical_font (self->priv->titleLabel, "EmpSystemFont");
 	GtkWidget *titleBox = gtk_hbox_new (FALSE, 0);
@@ -171,7 +170,20 @@ void personal_ip_address_content_create (PersonalIpAddress *self)
 	
 	gtk_box_pack_start (GTK_BOX (self->priv->contents), titleBox, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (self->priv->contents), ipBox, FALSE, FALSE, 0);
-    gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->contents), FALSE, FALSE, 0);
+    gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), GTK_WIDGET (self->priv->contents), FALSE, FALSE, 0);*/
+	
+	GtkWidget *image = gtk_image_new_from_icon_name ("personal-ip-address", GTK_ICON_SIZE_BUTTON);
+	GtkWidget *box = gtk_hbox_new (FALSE, 0);
+	self->priv->ipContent = gtk_label_new ("255.255.255.255");
+	gtk_box_pack_start (GTK_BOX (box), image, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (box), self->priv->ipContent, TRUE, TRUE, 0);
+	//hildon_helper_set_logical_font (self->priv->ipContent, "SmallSystemFont");
+	hildon_helper_set_logical_color (self->priv->ipContent, GTK_RC_FG, GTK_STATE_NORMAL, "ActiveTextColor");
+	gtk_misc_set_alignment (GTK_MISC (self->priv->ipContent), 1, 0.8);
+	gtk_misc_set_padding (GTK_MISC (self->priv->ipContent), HILDON_MARGIN_DEFAULT, HILDON_MARGIN_HALF);
+
+	gtk_box_pack_start (GTK_BOX (self->priv->contents), box, FALSE, FALSE, 0);
+	gtk_box_pack_start (GTK_BOX (self->priv->homeWidget), self->priv->contents, FALSE, FALSE, 0);
 	
     gtk_widget_show_all (self->priv->homeWidget);
 }
@@ -423,17 +435,17 @@ static void personal_ip_address_init (PersonalIpAddress *self)
 	//hd_home_plugin_item_set_settings (&self->parent, TRUE);
 	//g_signal_connect (&self->parent, "show-settings", G_CALLBACK (personal_ip_address_settings), self);
 
-	gtk_window_set_default_size (GTK_WINDOW (self), 215, 90);
+	gtk_window_set_default_size (GTK_WINDOW (self), 270, 56);
 	
 	self->priv->homeWidget = gtk_vbox_new (FALSE, 0);
 	gtk_container_add (GTK_CONTAINER (self), self->priv->homeWidget);
 	gtk_widget_show (self->priv->homeWidget);
 
 	GdkGeometry hints;
-	hints.min_width = 215;
-	hints.min_height = 90;
-	hints.max_width = 215;
-	hints.max_height = 90;
+	hints.min_width = 270;
+	hints.min_height = 56;
+	hints.max_width = 270;
+	hints.max_height = 56;
 	gtk_window_set_geometry_hints (GTK_WINDOW (self), self->priv->homeWidget, &hints, GDK_HINT_MIN_SIZE | GDK_HINT_MAX_SIZE);
 	
 	//personal_ip_address_read_settings (self);
